@@ -2,12 +2,14 @@ use 5.012;
 use strict;
 use warnings;
 
+# Artificial stupidity is easier to develop than artificial intelligence. 
+
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
-use Exporter::Shiny qw( theory );
+use Exporter::Shiny qw( theory bad_punctuation );
 use List::Util 1.54 ();
 
 sub _RANDOM_ {
@@ -20,7 +22,7 @@ sub _MERGE_ {
 	%$redstring = ( %$redstring, %new );
 }
 
-sub _UCFIRST_ ($) {
+sub _UCFIRST_ ($) { # Some sentences start with a non-word character like a quote mark
 	( my $str = shift )
 		=~ s/ (\w) / uc($1) /xe;
 	$str;
@@ -76,13 +78,13 @@ sub shady_group {
 			{ plural => 0, name => 'Opus Dei' },
 			{ plural => 0, name => 'the Priory of Sion', shortname => 'the Priory' },
 			{ plural => 0, name => 'GameStop' },
-			{ plural => 0, name => 'the British Royal Family', shortname => 'the Royals' },
+			{ plural => 0, splural => 1, name => 'the British Royal Family', shortname => 'the Royals' },
 			{ plural => 0, name => 'NASA' },
 			{ plural => 1, name => 'the Zionists' },
 			{ plural => 0, name => 'the Trump administration' },
 			{ plural => 0, name => 'the Biden administration' },
-			{ plural => 0, name => 'the Republican party', shortname => 'the Republicans' },
-			{ plural => 0, name => 'the Democrat party', shortname => 'the Democrats' },
+			{ plural => 0, splural => 1, name => 'the Republican party', shortname => 'the Republicans' },
+			{ plural => 0, splural => 1, name => 'the Democrat party', shortname => 'the Democrats' },
 			{ plural => 0, name => 'the New World Order' },
 			{ plural => 1, name => 'the Communists' },
 			{ plural => 0, name => 'the Shadow Government' },
@@ -90,7 +92,7 @@ sub shady_group {
 			{ plural => 0, name => 'the global scientific elite' },
 			{ plural => 0, name => 'Big Pharma' },
 			{ plural => 0, name => 'Big Tobacco' },
-			{ plural => 1, name => 'the lizard people', shortname => 'the lizardmen' },
+			{ plural => 1, splural => 1, name => 'the lizard people', shortname => 'the lizardmen' },
 			{ plural => 1, name => 'the grey aliens', shortname => 'the aliens' },
 			{ plural => 1, name => 'the big Hollywood studios', shortname => 'Hollywood' },
 			{ plural => 0, name => 'the music industry' },
@@ -252,6 +254,7 @@ sub disease {
 		'diabetes',
 		'obesity',
 		'autism',
+		'Ebola',
 	);
 	
 	_MERGE_( $redstring, disease => $disease );
@@ -376,6 +379,7 @@ sub bad_place {
 			my $p = random_place( $redstring );
 			"a secret base in $p";
 		},
+		'a facility inside the hollow Earth', 
 	);
 	
 	_MERGE_( $redstring, bad_place => $bad_place );
@@ -511,24 +515,27 @@ sub precious_resource_with_quantity {
 
 sub mind_control_device {
 	my $redstring = shift // {};
-	
-	my $mc = _RANDOM_(
-		'chemtrails',
-		'mind control drugs in the water',
-		'5G',
-		'WiFi',
-		'microchips implanted at birth',
-		'vaccines',
-		'childhood indoctrination',
-		'neurolinguistic programming',
-		'video games',
-		'mass media',
-		'space lasers',
-		'hypnotism',
+
+	my @mc = (
+		['chemtrails', 1],
+		['mind control drugs in the water', 1],
+		['5G', 0],
+		['WiFi', 0],
+		['microchips implanted at birth', 1],
+		['vaccines', 1],
+		['childhood indoctrination', 0],
+		['neurolinguistic programming', 0],
+		['video games', 1],
+		['mass media', 1],
+		['space lasers', 1],
+		['hypnotism', 0],
 	);
 	
-	_MERGE_( $redstring, mind_control_device => $mc );
-	return $mc;
+	my $mc = _RANDOM_(@mc);
+	
+	_MERGE_( $redstring, mind_control_device => $mc->[0] );
+	_MERGE_( $redstring, mind_control_device_plural => $mc->[1] );
+	return $mc->[0];
 }
 
 sub future_time {
@@ -547,13 +554,21 @@ sub future_time {
 	return $time;
 }
 
+sub splural {
+	my $a = shift;
+	if (defined $a->{splural}) {
+		return $a->{splural};
+	}
+	return $a->{plural};
+}
+
 sub a_long_time {
 	my $redstring = shift // {};
 	
 	my @extras = ();
 	for my $actor ( qw/ protagonists antagonists / ) {
 		push @extras, sub {
-			my $have = $redstring->{$actor}{plural} ? 'have' : 'has';
+			my $have = splural( $redstring->{$actor} ) ? 'have' : 'has';
 			"for as long as " . ($redstring->{$actor}{shortname}//$redstring->{$actor}{name}) . " $have existed";
 		} if $redstring->{$actor}{name};
 	}
@@ -721,6 +736,23 @@ sub website {
 	return $x;
 }
 
+sub fatuous {
+	my $redstring = shift // {};
+
+	my $x = _RANDOM_(
+		"We all know what's going on here.",
+		"It's plain and simple common sense.",
+		'Most people are in denial.',
+		"Isn't it obvious?",
+		"Wake up, sheeple!",
+		"It's obvious if you connect the dots.",
+		"They leave clues to mock us.",
+	);
+
+	_MERGE_( $redstring, clone => $x );
+	return $x;
+}
+
 sub clone {
 	my $redstring = shift // {};
 
@@ -862,7 +894,8 @@ sub evidence {
 			$f->{title} . " is satanic",
 			sub {
 				my $g = shady_group( $redstring );
-				$f->{author} . " has ties to $g";
+				my $has = splural( $redstring->{shady_group} ) ? 'have' : 'has';
+				$f->{author} . " $has ties to $g";
 			},
 			sub {
 				my $b = bad_place( $redstring );
@@ -894,11 +927,20 @@ sub evidence {
 	
 	if ( my $mc = $redstring->{mind_control_device} ) {
 		my $time = a_long_time();
+		my $mcp = $redstring->{mind_control_device_plural};
+		my $is = 'is';
+		my $has = 'has';
+		my $was = 'was';
+		if ($mcp) {
+			$is = 'are';
+			$has = 'have';
+			$was = 'were';
+		}
 		push @x, (
-			"everybody knows $mc is real",
-			sub { "$mc has been researched by ${ \ shady_group($redstring) } $time" },
-			sub { "$mc was used to conceal ${ \ shady_group($redstring) } $time" },
-			sub { "$mc was used to infiltrate ${ \ shady_group($redstring) }" },
+			"everybody knows $mc $is real",
+			sub { "$mc $has been researched by ${ \ shady_group($redstring) } $time" },
+			sub { "$mc $was used to conceal ${ \ shady_group($redstring) } $time" },
+			sub { "$mc $was used to infiltrate ${ \ shady_group($redstring) }" },
 		);
 	}
 
@@ -939,12 +981,13 @@ sub evidence {
 	}
 
 	if ( my $r = $redstring->{precious_resource} ) {
-		my ( $bad, $are );
+		my ( $bad, $are, $r_are );
 		$redstring->{shady_group}{name} or shady_group( $redstring );
 		foreach ( qw/ antagonist protagonist shady_group / ) {
 			if ( $redstring->{$_}{name} ) {
 				$bad = $redstring->{$_}{name};
 				$are = $redstring->{$_}{plural} ? 'are' : 'is';
+				$r_are = ($r =~ /s$/) ? 'are' : 'is';
 			}
 		}
 		push @x, (
@@ -952,8 +995,8 @@ sub evidence {
 			"$bad keeps buying $r secretly on the stock market",
 			"the global supply of $r is at an all time low",
 			"have you ever seen $r for real with your own eyes",
-			"$r is so damn expensive",
-			"$r is really rare",
+			"$r $r_are so damn expensive",
+			"$r $r_are really rare",
 			"Alex Jones says $bad $are linked to $r",
 		);
 	}
@@ -980,6 +1023,7 @@ sub evidence {
 			// shady_group( $redstring );
 		push @x, (
 			"the Wikipedia entry for $p keeps getting edited by $bad",
+			# This has singular/plural problems - how to solve?
 			"$bad has ties to $p",
 			"$p probably isn't a real place anyway",
 		);
@@ -989,9 +1033,10 @@ sub evidence {
 		next unless $redstring->{$actor}{name};
 		
 		my $name   = $redstring->{$actor}{shortname} // $redstring->{$actor}{name};
-		my $have   = $redstring->{$actor}{plural} ? 'have' : 'has';
-		my $are    = $redstring->{$actor}{plural} ? 'are'  : 'is';
-		my $s      = $redstring->{$actor}{plural} ? ''     : 's';
+		my $have   = splural( $redstring->{$actor} ) ? 'have' : 'has';
+		my $are    = splural( $redstring->{$actor} ) ? 'are'  : 'is';
+		my $s      = splural( $redstring->{$actor} ) ? ''     : 's';
+		my $ies    = splural( $redstring->{$actor} ) ? 'y'    : 'ies';
 		
 		( my $fbname = $name ) =~ s/^the //i;
 		$fbname = _UCFIRST_ $fbname;
@@ -1005,7 +1050,7 @@ sub evidence {
 			"the '$fbname Truth' Facebook page says so",
 			"the '$fbname Exposed' website says so",
 			"$name even admit$s it",
-			"$name deny$s it but that is obvious lies",
+			"$name den$ies it but that is obvious lies",
 		);
 		
 		if ( my $animal = $redstring->{real_animal} // $redstring->{fake_animal} ) {
@@ -1033,28 +1078,26 @@ sub evidence {
 	if ( @evidences == 2 ) {
 		my ( $e1, $e2 ) = @evidences;
 		return _RANDOM_(
-			"You can tell this is the truth because $e1 and $e2.",
-			( ( "I know because $e1 and $e2." ) x 6 ),
+			"You can tell this is the truth because $e1, and $e2.",
+			( ( "I know because $e1, and $e2." ) x 6 ),
 			"You just need to connect the dots. " . _UCFIRST_( "$e1 and $e2." ),
-			"I used to be asleep like you, but then I saw the clues. " . _UCFIRST_( "$e1 and $e2. WAKE UP!" ),
-			"THEY HIDE THE TRUTH IN PLAIN SIGHT. " . _UCFIRST_( "$e1 and $e2." ),
-			"You won't believe how deep the rabbit hole goes. " . _UCFIRST_( "$e1 and $e2." ),
-			_UCFIRST_( "$e1 and $e2. It's obvious if you connect the dots." ),
-			_UCFIRST_( "$e1 and $e2. They leave clues to mock us." ),
-			_UCFIRST_( "$e1 and $e2. Isn't it obvious?" ),
-			_UCFIRST_( "$e1 and $e2. Wake up, sheeple!" ),
+			"I used to be asleep like you, but then I saw the clues. " . _UCFIRST_( "$e1, and $e2. WAKE UP!" ),
+			"THEY HIDE THE TRUTH IN PLAIN SIGHT. " . _UCFIRST_( "$e1, and $e2." ),
+			"You won't believe how deep the rabbit hole goes. " . _UCFIRST_( "$e1, and $e2." ),
+			sub { _UCFIRST_("$e1, and $e2. " . fatuous()) },
 			sub {
 				my $e3 = uc _RANDOM_(@x);
-				_UCFIRST_( "$e1 and $e2. Isn't it obvious? $e3!" );
+				my $fatuous = fatuous();
+				_UCFIRST_( "$e1, and $e2. $fatuous $e3!" );
 			},
 			sub {
 				my $e3 = uc _RANDOM_(@x);
-				_UCFIRST_( "$e1 and $e2. They leave clues to mock us! $e3! MOCK! MOCK!" );
+				_UCFIRST_( "$e1, and $e2. They leave clues to mock us! $e3! MOCK! MOCK!" );
 			},
 			sub {
 				my $t = {};
 				theory($t);
-				_UCFIRST_( "$e1 and $e2. Isn't it obvious? Also: " . $t->{base_theory} );
+				_UCFIRST_( "$e1, and $e2. Isn't it obvious? Also: " . $t->{base_theory} );
 			},
 		);
 	}
@@ -1063,7 +1106,7 @@ sub evidence {
 		return _RANDOM_(
 			"You can tell the truth because $e1.",
 			_UCFIRST_("$e1 and that reveals the truth."),
-			"The truth is obvious if you're not a sheep - $e1.",
+			"The truth is obvious if you're not a sheep, $e1.",
 		);
 	}
 	
@@ -1105,13 +1148,17 @@ sub hidden_truth {
 					"viruses aren't real";
 				},
 				sub {
-					$redstring->{topic} = { name => 'MKUltra', plural => 1 };
+					$redstring->{topic} = { name => 'MKUltra', plural => 0 };
 					"MKUltra is still happening";
 				},
 				sub {
-					$redstring->{topic} = { name => 'Jeffrey Epstein', plural => 1 };
+					$redstring->{topic} = { name => 'Jeffrey Epstein', plural => 0 };
 					"Epstein didn't kill himself";
 				},
+				sub {
+					$redstring->{topic} = { name => "Sgt Pepper's Lonely Hearts Club Band", plural => 0 };
+					"Paul McCartney died in a car crash in 1966";
+				},
 				sub {
 					$redstring->{topic} = { name => 'Stonehenge', plural => 0 };
 					$redstring->{random_place} //= 'Somerset';
@@ -1142,11 +1189,37 @@ sub hidden_truth {
 					$redstring->{random_place} //= 'New York';
 					"9/11 was an inside job";
 				},
+				sub {
+					my $badevent = _RANDOM_(
+						'Columbine',
+						'Sandy Hook',
+						'the Boston Marathon Bombing',
+					);
+					$redstring->{topic} = { name => 'false flag operations', plural => 1 };
+					"$badevent was orchestrated by the US government";
+				},
 				sub {
 					$redstring->{topic} = { name => 'glaciers', plural => 1 };
 					$redstring->{random_place} //= 'Greenland';
 					"global warming is a hoax";
 				},
+				sub {
+					$redstring->{topic} = { name => 'geology', plural => 0 };
+					'the US government knows exactly when Yellowstone will erupt';
+				},
+				sub {
+					$redstring->{topic} = { name => 'cloud seeding', plural => 0 };
+					"the government controls the weather";
+				},
+				sub {
+					$redstring->{topic} = { name => 'Snapple', plural => 0 };
+					"Snapple is owned by the KKK";
+				},
+				sub {
+					my $disease = disease( $redstring );
+					$redstring->{topic} = { name => 'biological warfare', plural => 0 };
+					"$disease was developed as a bioweapon";
+				},
 				sub {
 					$redstring->{topic} = { name => 'gas chambers', plural => 1 };
 					$redstring->{random_place} //= 'Germany';
@@ -1464,7 +1537,8 @@ sub theory {
 					my $truth = hidden_truth();
 					my $pro   = $redstring->{protagonists}{shortname} // $protagonists;
 					my $ant   = $redstring->{antagonists}{shortname} // $antagonists;
-					_UCFIRST_ "$pro want to expose the truth that $truth and $ant will do whatever they can to stop them";
+					my $want = splural( $redstring->{protagonists} ) ? 'want' : 'wants';
+					_UCFIRST_ "$pro $want to expose the truth that $truth and $ant will do whatever they can to stop them";
 				},
 			);
 			
@@ -1757,6 +1831,11 @@ sub theory {
 					$redstring->{topic} = { name => 'oncology', plural => 0 };
 					"windmills cause cancer";
 				},
+				sub {
+					my $chem = chemicals( $redstring );
+					$redstring->{topic} = { name => 'honey', plural => 0 };
+					"$chem is killing all the bees";
+				},
 				sub {
 					my $animal = real_animal( $redstring );
 					$redstring->{topic} = { name => 'space flight', plural => 0 };
@@ -1854,7 +1933,7 @@ sub theory {
 		my $group1 = $redstring->{protagonists}{shortname} // $redstring->{protagonists}{name};
 		my $group2 = shady_group( $redstring );
 		$redstring->{antagonists} = $redstring->{shady_group};
-		my $know = $redstring->{antagonists}->{plural} ? 'know' : 'knows';
+		my $know = splural ($redstring->{antagonists}) ? 'know' : 'knows';
 		$theory .= " " . _UCFIRST_ _RANDOM_(
 			sub {
 				my $bribe = precious_resource_with_quantity( $redstring );
@@ -1910,7 +1989,8 @@ sub numerology {
 	my $redstring = shift // {};
 	
 	my @strings = List::Util::uniq(
-		map { my $letters = uc( $_ ); $letters =~ s/[^A-Z]//g; $letters }
+		grep { length }
+		map { my $letters = uc( $_ ); $letters =~ s/[^A-Z0-9]//g; $letters }
 		map {
 			/^(the )(.+)$/i ? $2 : $_
 		}
@@ -1924,7 +2004,7 @@ sub numerology {
 	foreach my $string ( @strings ) {
 		next if length($string) >= 20;
 		my @letters = split //, $string;
-		my @numbers = map ord($_) - 0x40, @letters;
+		my @numbers = map /[A-Z]/ ? ( ord($_) - 0x40 ) : $_, @letters;
 		my $sum     = List::Util::sum( @numbers );
 		
 		push @{ $calcs{$sum} ||= [] }, sprintf(
@@ -1966,6 +2046,15 @@ sub numerology {
 	return '';
 }
 
+sub bad_punctuation {
+	my ( $string, $cancel ) = @_;
+	unless ( $cancel ) {
+		$string =~ s/ (\w) ([,!?]) / $1 . _RANDOM_(    $2, " $2", " $2", " $2$2") /exg;
+		$string =~ s/ (\w) ([.])   / $1 . _RANDOM_($2, $2, " $2", " ", " $2$2$2") /exg;
+	}
+	return $string;
+}
+
 1;
 
 __END__
@@ -1981,16 +2070,19 @@ Acme::ConspiracyTheory::Random - random theories
 =head1 SYNOPSIS
 
   use feature 'say';
-  use Acme::ConspiracyTheory::Random 'theory';
+  use Acme::ConspiracyTheory::Random -all;
   
-  say theory();
+  say bad_punctuation( theory() );
 
 =head1 DESCRIPTION
 
-This module exports one function, C<< theory() >> which returns a string.
+This module exports a function, C<< theory() >> which returns a string.
 
 =for html <p><img src="https://raw.githubusercontent.com/tobyink/p5-acme-conspiracytheory-random/master/assets/pepe-silvia.jpeg" alt=""></p>
 
+There is also a function C<< bad_punctuation >> which, given a string, might
+make the punctuation worse.
+
 =head1 BUGS
 
 Please report any bugs to
@@ -2004,6 +2096,14 @@ REDACTED
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
+=head1 CONTRIBUTORS
+
+Alex Jones discovered that there are secretly other people who have contributed
+to this module but Toby Inkster is working with Microsoft and the Illuminati to
+cover it up. I tried to blog about it but all my posts keep getting taken down
+from Tumblr. There are hidden clues on L<GitHub|https://github.com/tobyink/p5-acme-conspiracytheory-random/graphs/contributors>.
+You don't want to know how deep this rabbit hole goes!
+
 =head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2021 by Toby Inkster.
